@@ -11,7 +11,6 @@ from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.core.mail import send_mail
 from django.core.management.base import BaseCommand
-from django.db import transaction
 from django.db.models.query_utils import Q
 from django.template.loader import render_to_string
 from django.utils.safestring import mark_safe
@@ -450,7 +449,6 @@ class Command(BaseCommand):
             entry['language'] = language
             entry['species']['language'] = language
 
-    @transaction.commit_on_success
     def add_or_update_checklist(self, values, messages):
         location = find_map_location(values['location']['name'])
         if not location:
