@@ -127,8 +127,8 @@ class Map(ChecklistsModel):
         verbose_name_plural = _('maps')
 
     name = CharField(max_length=40)
-    content_type = ForeignKey(ContentType)
-    object_id = PositiveIntegerField()
+    content_type = ForeignKey(ContentType, editable=False)
+    object_id = PositiveIntegerField(editable=False)
     content_object = GenericForeignKey('content_type', 'object_id')
 
     name.verbose_name = _('name')
