@@ -6,10 +6,12 @@ existing database.
 """
 
 from checklists import get_data_path
-from checklists.models import Activity
+from checklists.models import Activity, set_current_user, clear_current_user
 
 from utils import create_objects, get_object_data
 
 
 def run():
+    set_current_user('load_activities')
     create_objects(Activity, get_object_data(get_data_path('activity'), 'slug'))
+    clear_current_user()
