@@ -49,7 +49,10 @@ class LanguageFieldMixin:
         for field in fields:
             for code, name in settings.LANGUAGES:
                 i18n_field = "%s_%s" % (field, code)
-                kwargs[i18n_field] = u"%s %s" % (name, kwargs[field])
+                if kwargs[field]:
+                    kwargs[i18n_field] = u"%s %s" % (name, kwargs[field])
+                else:
+                    kwargs[i18n_field] = kwargs[field]
             del kwargs[field]
         return kwargs
 
